"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.VlsChecker = exports.createDiagnostic = void 0;
const vite_plugin_checker_1 = require("vite-plugin-checker");
const worker_threads_1 = require("worker_threads");
const diagnostics_1 = require("./commands/diagnostics");
const createDiagnostic = (userOptions = {}) => {
    let overlay = true; // Vite defaults to true
    return {
        config: ({ hmr }) => {
            const viteOverlay = !(typeof hmr === 'object' && hmr.overlay === false);
            if (userOptions.overlay === false || !viteOverlay) {
                overlay = false;
            }
        },
        configureServer({ root }) {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const workDir = (_a = userOptions.root) !== null && _a !== void 0 ? _a : root;
                const errorCallback = (diagnostics, overlayErr) => {
                    if (!overlay)
                        return;
                    if (!overlayErr)
                        return;
                    worker_threads_1.parentPort === null || worker_threads_1.parentPort === void 0 ? void 0 : worker_threads_1.parentPort.postMessage({
                        type: 'ERROR',
                        payload: {
                            type: 'error',
                            err: overlayErr,
                        },
                    });
                };
                yield diagnostics_1.diagnostics(workDir, 'WARN', { watch: true, errorCallback, verbose: false });
            });
        },
    };
};
exports.createDiagnostic = createDiagnostic;
const { mainScript, workerScript } = vite_plugin_checker_1.createScript({
    absFilename: __filename,
    buildBin: ['vite-plugin-checker-vls', ['diagnostics']],
    serverChecker: { createDiagnostic: exports.createDiagnostic },
});
if (worker_threads_1.isMainThread) {
    const configCurryFn = (vlsConfig) => {
        return (sharedConfig, env) => {
            const createChecker = mainScript();
            return createChecker(Object.assign({ vls: vlsConfig }, sharedConfig), env);
        };
    };
    module.exports.VlsChecker = configCurryFn;
    module.exports.createServeAndBuild = configCurryFn;
}
else {
    workerScript();
}
